==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-jpa/src/test/java/org/apache/camel/processor/jpa/JpaPollingConsumerTimeoutTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.jpa;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.examples.Customer;
import org.apache.camel.spring.SpringRouteBuilder;

public class JpaPollingConsumerTimeoutTest extends JpaPollingConsumerTest {

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new SpringRouteBuilder() {
            public void configure() {
                from("direct:start")
                    .pollEnrich().simple("jpa://" + Customer.class.getName() + "?query=select c from Customer c where c.name like '${header.name}'")
                        .timeout(5000)
                        .aggregationStrategy((a, b) -> {
                            String name = b.getIn().getBody(Customer.class).getName();
                            String phrase = a.getIn().getBody(String.class).replace("NAME", name);
                            a.getIn().setBody(phrase);
                            return a;
                        })
                    .to("mock:result");
            }
        };
    }

}

==> apache-camel-3.5.0-src.zip: apache-camel-3.5.0/components/camel-jpa/src/test/java/org/apache/camel/processor/jpa/JpaPollingConsumerTimeoutTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.jpa;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.examples.Customer;
import org.apache.camel.spring.SpringRouteBuilder;

public class JpaPollingConsumerTimeoutTest extends JpaPollingConsumerTest {

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new SpringRouteBuilder() {
            public void configure() {
                from("direct:start")
                        .pollEnrich()
                        .simple("jpa://" + Customer.class.getName()
                                + "?query=select c from Customer c where c.name like '${header.name}'")
                        .timeout(5000)
                        .aggregationStrategy((a, b) -> {
                            String name = b.getIn().getBody(Customer.class).getName();
                            String phrase = a.getIn().getBody(String.class).replace("NAME", name);
                            a.getIn().setBody(phrase);
                            return a;
                        })
                        .to("mock:result");
            }
        };
    }

}
